
"""
PDG MonteCarlo Numbering Scheme

Extracted from the 2006 version
http://cepa.fnal.gov/psm/stdhep/
"""

PDG_CODES = {
    # Quark and leptons
    1: "d",
    2: "u",
    3: "s",
    4: "c",
    5: "b",
    6: "t",
    7: "b^{\\prime}",
    8: "t^{\\prime}",
    11: "e^-",
    -11: "e^+",
    12: "\\nu_e",
    13: "\\mu^-",
    -13: "\\mu^+",
    14: "\\nu_\\mu",
    15: "\\tau^-",
    -15: "\\tau^+",
    16: "\\nu_\\tau",
    17: "\\tau^{\\prime -}",
    -17: "\\tau^{\\prime +}",
    18: "\\nu_{\\tau^{\\prime}}",

    # Gauge and Higgs Bosons
    21: "g",
    9: "g",
    22: "\\gamma",
    23: "Z^0",
    24: "W^+",
    -24: "W^-",
    25: "h^0 / H_1^0",
    32: "Z^{\\prime} / Z_2^0",
    33: "Z^{\\prime\\prime} / Z_3^0",
    34: "W^{\\prime}  / W_2^+",
    -34: "W^{\\prime}  / W_2^-",
    35: "H^0 / H_2^0",
    36: "A^0 / H_3^0",
    37: "H^+",
    -37: "H^-",

    # Special and non-standard particles and internal codes
    39: "G",
    41: "R^0",
    42: "LQ^c",
    110: "reggeon",
    990: "pomeron",
    9990: "odderon",

    # Diquarks
    1103: "(dd)_1",
    2101: "(ud)_0",
    2103: "(ud)_1",
    2203: "(uu)_1",
    3101: "(sd)_0",
    3103: "(sd)_1",
    3201: "(su)_0",
    3203: "(su)_1",
    3303: "(ss)_1",
    4101: "(cd)_0",
    4103: "(cd)_1",
    4201: "(cu)_0",
    4203: "(cu)_1",
    4301: "(cs)_0",
    4303: "(cs)_1",
    4403: "(cc)_1",
    5101: "(bd)_0",
    5103: "(bd)_1",
    5201: "(bu)_0",
    5203: "(bu)_1",
    5301: "(bs)_0",
    5303: "(bs)_1",
    5401: "(bc)_0",
    5403: "(bc)_1",
    5503: "(bb)_1",

    # R-Hadrons
    1000993: "R^0_{\\tilde gg}",
    1009113: "R^0_{\\tilde gd\\bar d}",
    1009213: "R^+_{\\tilde gu\\bar d}",
    -1009213: "R^-_{\\tilde gu\\bar d}",
    1009223: "R^0_{\\tilde gu\\bar u}",
    1009313: "R^0_{\\tilde gd\\bar s}",
    1009323: "R^+_{\\tilde gu\\bar s}",
    -1009323: "R^-_{\\tilde gu\\bar s}",
    1009333: "R^0_{\\tilde gs\\bar s}",
    1091114: "R^-_{\\tilde gddd}",
    -1091114: "R^+_{\\tilde gddd}",
    1092114: "R^0_{\\tilde gudd}",
    1092214: "R^+_{\\tilde guud}",
    -1092214: "R^-_{\\tilde guud}",
    1092224: "R^{++}_{\\tilde guuu}",
    -1092224: "R^{--}_{\\tilde guuu}",
    1093114: "R^-_{\\tilde gsdd}",
    -1093114: "R^+_{\\tilde gsdd}",
    1093214: "R^0_{\\tilde gsud}",
    1093224: "R^+_{\\tilde gsuu}",
    -1093224: "R^-_{\\tilde gsuu}",
    1093314: "R^-_{\\tilde gssd}",
    -1093314: "R^+_{\\tilde gssd}",
    1093324: "R^0_{\\tilde gssu}",
    1093334: "R^-_{\\tilde gsss}",
    -1093334: "R^+_{\\tilde gsss}",
    1000612: "R^+_{\\tilde t_1\\bar d}",
    -1000612: "R^-_{\\tilde t_1\\bar d}",
    1000622: "R^0_{\\tilde t_1\\bar u}",
    1000632: "R^+_{\\tilde t_1\\bar s}",
    -1000632: "R^-_{\\tilde t_1\\bar s}",
    1000642: "R^0_{\\tilde t_1\\bar c}",
    1000652: "R^+_{\\tilde t_1\\bar b}",
    -1000652: "R^-_{\\tilde t_1\\bar b}",
    1006113: "R^0_{\\tilde t_1dd_1}",
    1006211: "R^+_{\\tilde t_1ud_0}",
    -1006211: "R^-_{\\tilde t_1ud_0}",
    1006213: "R^+_{\\tilde t_1ud_1}",
    -1006213: "R^-_{\\tilde t_1ud_1}",
    1006223: "R^{++}_{\\tilde t_1uu_1}",
    -1006223: "R^{--}_{\\tilde t_1uu_1}",
    1006311: "R^0_{\\tilde t_1sd_0}",
    1006313: "R^0_{\\tilde t_1sd_1}",
    1006321: "R^+_{\\tilde t_1su_0}",
    -1006321: "R^-_{\\tilde t_1su_0}",
    1006323: "R^+_{\\tilde t_1su_1}",
    -1006323: "R^-_{\\tilde t_1su_1}",
    1006333: "R^0_{\\tilde t_1ss_1}",

    # Supersymmetric Particles
    1000001: "\\tilde d_L",
    1000002: "\\tilde u_L",
    1000003: "\\tilde s_L",
    1000004: "\\tilde c_L",
    1000005: "\\tilde b_1",
    1000006: "\\tilde t_1",
    1000011: "\\tilde e_L^-",
    -1000011: "\\tilde e_L^+",
    1000012: "\\tilde \\nu_{e L}",
    1000013: "\\tilde \\mu_L^-",
    -1000013: "\\tilde \\mu_L^+",
    1000014: "\\tilde \\nu_{\\mu L}",
    1000015: "\\tilde \\tau_1^-",
    -1000015: "\\tilde \\tau_1^+",
    1000016: "\\tilde \\nu_{\\tau L}",
    2000001: "\\tilde d_R",
    2000002: "\\tilde u_R",
    2000003: "\\tilde s_R",
    2000004: "\\tilde c_R",
    2000005: "\\tilde b_2",
    2000006: "\\tilde t_2",
    2000011: "\\tilde e_R^-",
    -2000011: "\\tilde e_R^+",
    2000012: "\\tilde \\nu_{e R}",
    2000013: "\\tilde \\mu_R^-",
    -2000013: "\\tilde \\mu_R^+",
    2000014: "\\tilde \\nu_{\\mu R}",
    2000015: "\\tilde \\tau_2^-",
    -2000015: "\\tilde \\tau_2^+",
    2000016: "\\tilde \\nu_{\\tau R}",
    1000021: "\\tilde g",
    1000022: "\\tilde \\chi_1^0",
    1000023: "\\tilde \\chi_2^0",
    1000024: "\\tilde \\chi_1^+",
    -1000024: "\\tilde \\chi_1^-",
    1000025: "\\tilde \\chi_3^0",
    1000035: "\\tilde \\chi_4^0",
    1000037: "\\tilde \\chi_2^+",
    -1000037: "\\tilde \\chi_2^-",
    1000039: "\\tilde G",

    # Technicolor and Excited Particles
    3000111: "\\pi_{tech}^0",
    3000211: "\\pi_{tech}^+",
    -3000211: "\\pi_{tech}^-",
    3000221: "\\pi^{\\prime0}_{tech}",
    3100221: "\\eta_{tech}^0",
    3000113: "\\rho_{tech}^0",
    3000213: "\\rho_{tech}^+",
    -3000213: "\\rho_{tech}^-",
    3000223: "\\omega_{tech}^0",
    3100021: "V_8",
    3060111: "\\pi_{tech,22}^1",
    3160111: "\\pi_{tech,22}^8",
    3130113: "\\rho_{tech,11}",
    3140113: "\\rho_{tech,12}",
    3150113: "\\rho_{tech,21}",
    3160113: "\\rho_{tech,22}",
    4000001: "d^*",
    4000002: "u^*",
    4000011: "e^*",
    4000012: "\\nu_e^*",

    # Pentaquarks
    9221132: "\\Theta^+",
    -9221132: "\\Theta^-",
    9331122: "\\Phi^{--}",
    -9331122: "\\Phi^{++}",

    # Light I=1 Mesons
    111: "\\pi^0",
    211: "\\pi^+",
    -211: "\\pi^-",
    9000111: "a_0^0(980)",
    9000211: "a_0^+(980)",
    -9000211: "a_0^-(980)",
    100111: "\\pi^0(1300)",
    100211: "\\pi^+(1300)",
    -100211: "\\pi^-(1300)",
    10111: "a_0^0(1450)",
    10211: "a_0^+(1450)",
    -10211: "a_0^-(1450)",
    9010111: "\\pi^0(1800)",
    9010211: "\\pi^+(1800)",
    -9010211: "\\pi^-(1800)",
    113: "\\rho^0(770)",
    213: "\\rho^+(770)",
    -213: "\\rho^-(770)",
    10113: "b_1^0(1235)",
    10213: "b_1^+(1235)",
    -10213: "b_1^-(1235)",
    20113: "a_1^0(1260)",
    20213: "a_1^+(1260)",
    -20213: "a_1^-(1260)",
    9000113: "\\pi_1^0(1400)",
    9000213: "\\pi_1^+(1400)",
    -9000213: "\\pi_1^-(1400)",
    100113: "\\rho^0(1450)",
    100213: "\\rho^+(1450)",
    -100213: "\\rho^-(1450)",
    9010113: "\\pi_1^0(1600)",
    9010213: "\\pi_1^+(1600)",
    -9010213: "\\pi_1^-(1600)",
    9020113: "a_1^0(1640)",
    9020213: "a_1^+(1640)",
    -9020213: "a_1^-(1640)",
    30113: "\\rho^0(1700)",
    30213: "\\rho^+(1700)",
    -30213: "\\rho^-(1700)",
    9030113: "\\rho^0(1900)",
    9030213: "\\rho^+(1900)",
    -9030213: "\\rho^-(1900)",
    9040113: "\\rho^0(2150)",
    9040213: "\\rho^+(2150)",
    -9040213: "\\rho^-(2150)",

    # Light I=1 Mesons
    115: "a_2^0(1320)",
    215: "a_2^+(1320)",
    -215: "a_2^-(1320)",
    10115: "\\pi_2^0(1670)",
    10215: "\\pi_2^+(1670)",
    -10215: "\\pi_2^-(1670)",
    9000115: "a_2^0(1700)",
    9000215: "a_2^+(1700)",
    -9000215: "a_2^-(1700)",
    9010115: "\\pi_2^0(2100)",
    9010215: "\\pi_2^+(2100)",
    -9010215: "\\pi_2^-(2100)",
    117: "\\rho_3^0(1690)",
    217: "\\rho_3^+(1690)",
    -217: "\\rho_3^-(1690)",
    9000117: "\\rho_3^0(1990)",
    9000217: "\\rho_3^+(1990)",
    -9000217: "\\rho_3^-(1990)",
    9010117: "\\rho_3^0(2250)",
    9010217: "\\rho_3^+(2250)",
    -9010217: "\\rho_3^-(2250)",
    119: "a_4^0(2040)",
    219: "a_4^+(2040)",
    -219: "a_4^-(2040)",

    #  Light I=0 Mesons
    221: "\\eta",
    331: "\\eta^\\prime(958)",
    9000221: "f_0(600)",
    9010221: "f_0(980)",
    100221: "\\eta(1295)",
    10221: "f_0(1370)",
    9020221: "\\eta(1405)",
    100331: "\\eta(1475)",
    9030221: "f_0(1500)",
    10331: "f_0(1710)",
    9040221: "\\eta(1760)",
    9050221: "f_0(2020)",
    9060221: "f_0(2100)",
    9070221: "f_0(2200)",
    9080221: "\\eta(2225)",
    223: "\\omega(782)",
    333: "\\phi(1020)",
    10223: "h_1(1170)",
    20223: "f_1(1285)",
    10333: "h_1(1380)",
    20333: "f_1(1420)",
    100223: "\\omega(1420)",
    9000223: "f_1(1510)",
    9010223: "h_1(1595)",
    30223: "\\omega(1650)",
    100333: "\\phi(1680)",

    #  Light I=0 Mesons
    225: "f_2(1270)",
    9000225: "f_2(1430)",
    335: "f_2^\\prime(1525)",
    9010225: "f_2(1565)",
    9020225: "f_2(1640)",
    10225: "\\eta_2(1645)",
    9030225: "f_2(1810)",
    10335: "\\eta_2(1870)",
    9040225: "f_2(1910)",
    9050225: "f_2(1950)",
    9060225: "f_2(2010)",
    9070225: "f_2(2150)",
    9080225: "f_2(2300)",
    9090225: "f_2(2340)",
    227: "\\omega_3(1670)",
    337: "\\phi_3(1850)",
    229: "f_4(2050)",
    9000229: "f_J",
    9010229: "f_4(2300)",

    # Strange Mesons
    130: "K_L^0",
    310: "K_S^0",
    311: "K^0",
    321: "K^+",
    -321: "K^-",
    9000311: "K_0^{*0}(800)",
    9000321: "K_0^{*+}(800)",
    -9000321: "K_0^{*-}(800)",
    10311: "K_0^{*0}(1430)",
    10321: "K_0^{*+}(1430)",
    -10321: "K_0^{*-}(1430)",
    100311: "K^0(1460)",
    100321: "K^+(1460)",
    -100321: "K^-(1460)",
    9010311: "K^0(1830)",
    9010321: "K^+(1830)",
    -9010321: "K^-(1830)",
    9020311: "K^{*0}_0(1950)",
    9020321: "K^{*+}_0(1950)",
    -9020321: "K^{*-}_0(1950)",
    313: "K^{*0}(892)",
    323: "K^{*+}(892)",
    -323: "K^{*-}(892)",
    10313: "K_1^0(1270)",
    10323: "K_1^+(1270)",
    -10323: "K_1^-(1270)",
    20313: "K_1^0(1400)",
    20323: "K_1^+(1400)",
    -20323: "K_1^-(1400)",
    100313: "K^{*0}(1410)",
    100323: "K^{*+}(1410)",
    -100323: "K^{*-}(1410)",
    9000313: "K_1^0(1650)",
    9000323: "K_1^+(1650)",
    -9000323: "K_1^-(1650)",
    30313: "K^{*0}(1680)",
    30323: "K^{*+}(1680)",
    -30323: "K^{*-}(1680)",

    # Strange Mesons
    315: "K_2^{*0}(1430)",
    325: "K_2^{*+}(1430)",
    -325: "K_2^{*-}(1430)",
    9000315: "K_2^0(1580)",
    9000325: "K_2^+(1580)",
    -9000325: "K_2^-(1580)",
    10315: "K_2^0(1770)",
    10325: "K_2^+(1770)",
    -10325: "K_2^-(1770)",
    20315: "K_2^0(1820)",
    20325: "K_2^+(1820)",
    -20325: "K_2^-(1820)",
    9010315: "K_2^{*0}(1980)",
    9010325: "K_2^{*+}(1980)",
    -9010325: "K_2^{*-}(1980)",
    9020315: "K_2^0(2250)",
    9020325: "K_2^+(2250)",
    -9020325: "K_2^-(2250)",
    317: "K_3^{*0}(1780)",
    327: "K_3^{*+}(1780)",
    -327: "K_3^{*-}(1780)",
    9010317: "K_3^0(2320)",
    9010327: "K_3^+(2320)",
    -9010327: "K_3^-(2320)",
    319: "K_4^{*0}(2045)",
    329: "K_4^{*+}(2045)",
    -329: "K_4^{*-}(2045)",
    9000319: "K_4^0(2500)",
    9000329: "K_4^+(2500)",
    -9000329: "K_4^-(2500)",

    # Charmed Mesons
    411: "D^+",
    -411: "D^-",
    421: "D^0",
    10411: "D_0^{*+}(2400)",
    -10411: "D_0^{*-}(2400)",
    10421: "D_0^{*0}(2400)",
    413: "D^{*+}(2010)",
    -413: "D^{*-}(2010)",
    423: "D^{*0}(2007)",
    10413: "D_1^+(2420)",
    -10413: "D_1^-(2420)",
    10423: "D_1^0(2420)",
    20413: "D_1^+(H)",
    -20413: "D_1^-(H)",
    20423: "D_1^0(2430)",
    415: "D_2^{*+}(2460)",
    -415: "D_2^{*-}(2460)",
    425: "D_2^{*0}(2460)",
    431: "D_s^+",
    -431: "D_s^-",
    10431: "D_{s0}^{*+}(2317)",
    -10431: "D_{s0}^{*-}(2317)",
    433: "D_s^{*+}",
    -433: "D_s^{*-}",
    10433: "D_{s1}^+(2536)",
    -10433: "D_{s1}^-(2536)",
    20433: "D_{s1}^+(2460)",
    -20433: "D_{s1}^-(2460)",
    435: "D_{s2}^{*+}(2573)",
    -435: "D_{s2}^{*-}(2573)",

    # $c\\bar c$ Mesons
    441: "\\eta_c(1S)",
    10441: "\\chi_{c0}(1P)",
    100441: "\\eta_c(2S)",
    443: "J/\\psi(1S)",
    10443: "h_c(1P)",
    20443: "\\chi_{c1}(1P)",
    100443: "\\psi(2S)",
    30443: "\\psi(3770)",
    9000443: "\\psi(4040)",
    9010443: "\\psi(4160)",
    9020443: "\\psi(4415)",
    445: "\\chi_{c2}(1P)",
    100445: "\\chi_{c2}(2P)",

    # Bottom Mesons
    511: "B^0",
    521: "B^+",
    -521: "B^-",
    10511: "B_0^{*0}",
    10521: "B_0^{*+}",
    -10521: "B_0^{*-}",
    513: "B^{*0}",
    523: "B^{*+}",
    -523: "B^{*-}",
    10513: "B_1^0(L)",
    10523: "B_1^+(L)",
    -10523: "B_1^-(L)",
    20513: "B_1^0(H)",
    20523: "B_1^+(H)",
    -20523: "B_1^-(H)",
    515: "B_2^{*0}",
    525: "B_2^{*+}",
    -525: "B_2^{*-}",
    531: "B_s^0",
    10531: "B_{s0}^{*0}",
    533: "B_s^{*0}",
    10533: "B_{s1}^0(L)",
    20533: "B_{s1}^0(H)",
    535: "B_{s2}^{*0}",
    541: "B_c^+",
    -541: "B_c^-",
    10541: "B_{c0}^{*+}",
    -10541: "B_{c0}^{*-}",
    543: "B_c^{*+}",
    -543: "B_c^{*-}",
    10543: "B_{c1}^+(L)",
    -10543: "B_{c1}^-(L)",
    20543: "B_{c1}^+(H)",
    -20543: "B_{c1}^-(H)",
    545: "B_{c2}^{*+}",
    -545: "B_{c2}^{*-}",

    # $b\\bar b$ Mesons
    551: "\\eta_b(1S)",
    10551: "\\chi_{b0}(1P)",
    100551: "\\eta_b(2S)",
    110551: "\\chi_{b0}(2P)",
    200551: "\\eta_b(3S)",
    210551: "\\chi_{b0}(3P)",
    553: "\\Upsilon(1S)",
    10553: "h_b(1P)",
    20553: "\\chi_{b1}(1P)",
    30553: "\\Upsilon_1(1D)",
    100553: "\\Upsilon(2S)",
    110553: "h_b(2P)",
    120553: "\\chi_{b1}(2P)",
    130553: "\\Upsilon_1(2D)",
    200553: "\\Upsilon(3S)",
    210553: "h_b(3P)",
    220553: "\\chi_{b1}(3P)",
    300553: "\\Upsilon(4S)",
    9000553: "\\Upsilon(10860)",
    9010553: "\\Upsilon(11020)",
    555: "\\chi_{b2}(1P)",
    10555: "\\eta_{b2}(1D)",
    20555: "\\Upsilon_2(1D)",
    100555: "\\chi_{b2}(2P)",
    110555: "\\eta_{b2}(2D)",
    120555: "\\Upsilon_2(2D)",
    200555: "\\chi_{b2}(3P)",
    557: "\\Upsilon_3(1D)",
    100557: "\\Upsilon_3(2D)",

    #  Light Baryons
    2212: "p",
    2112: "n",
    2224: "\\Delta^{++}",
    -2224: "\\Delta^{--}",
    2214: "\\Delta^+",
    -2214: "\\Delta^-",
    2114: "\\Delta^0",
    1114: "\\Delta^-",
    -1114: "\\Delta^+",

    #  Strange Baryons
    3122: "\\Lambda",
    3222: "\\Sigma^+",
    -3222: "\\Sigma^-",
    3212: "\\Sigma^0",
    3112: "\\Sigma^-",
    -3112: "\\Sigma^+",
    3224: "\\Sigma^{*+}",
    -3224: "\\Sigma^{*-}",
    3214: "\\Sigma^{*0}",
    3114: "\\Sigma^{*-}",
    -3114: "\\Sigma^{*+}",
    3322: "\\Xi^0",
    3312: "\\Xi^-",
    -3312: "\\Xi^+",
    3324: "\\Xi^{*0}",
    3314: "\\Xi^{*-}",
    -3314: "\\Xi^{*+}",
    3334: "\\Omega^-",
    -3334: "\\Omega^+",

    #  Charmed Baryons
    4122: "\\Lambda_c^+",
    -4122: "\\Lambda_c^-",
    4222: "\\Sigma_c^{++}",
    -4222: "\\Sigma_c^{--}",
    4212: "\\Sigma_c^+",
    -4212: "\\Sigma_c^-",
    4112: "\\Sigma_c^0",
    4224: "\\Sigma_c^{*++}",
    -4224: "\\Sigma_c^{*--}",
    4214: "\\Sigma_c^{*+}",
    -4214: "\\Sigma_c^{*-}",
    4114: "\\Sigma_c^{*0}",
    4232: "\\Xi_c^+",
    -4232: "\\Xi_c^-",
    4132: "\\Xi_c^0",
    4322: "\\Xi_c^{\\prime +}",
    -4322: "\\Xi_c^{\\prime -}",
    4312: "\\Xi_c^{\\prime 0}",
    4324: "\\Xi_c^{*+}",
    -4324: "\\Xi_c^{*-}",
    4314: "\\Xi_c^{*0}",
    4332: "\\Omega_c^0",
    4334: "\\Omega_c^{*0}",
    4412: "\\Xi_{cc}^+",
    -4412: "\\Xi_{cc}^-",
    4422: "\\Xi_{cc}^{++}",
    -4422: "\\Xi_{cc}^{--}",
    4414: "\\Xi_{cc}^{*+}",
    -4414: "\\Xi_{cc}^{*-}",
    4424: "\\Xi_{cc}^{*++}",
    -4424: "\\Xi_{cc}^{*--}",
    4432: "\\Omega_{cc}^+",
    -4432: "\\Omega_{cc}^-",
    4434: "\\Omega_{cc}^{*+}",
    -4434: "\\Omega_{cc}^{*-}",
    4444: "\\Omega_{ccc}^{++}",
    -4444: "\\Omega_{ccc}^{--}",

    #  Bottom Baryons
    5122: "\\Lambda_b^0",
    5112: "\\Sigma_b^-",
    -5112: "\\Sigma_b^+",
    5212: "\\Sigma_b^0",
    5222: "\\Sigma_b^+",
    -5222: "\\Sigma_b^-",
    5114: "\\Sigma_b^{*-}",
    -5114: "\\Sigma_b^{*+}",
    5214: "\\Sigma_b^{*0}",
    5224: "\\Sigma_b^{*+}",
    -5224: "\\Sigma_b^{*-}",
    5132: "\\Xi_b^-",
    -5132: "\\Xi_b^+",
    5232: "\\Xi_b^0",
    5312: "\\Xi_b^{\\prime -}",
    -5312: "\\Xi_b^{\\prime +}",
    5322: "\\Xi_b^{\\prime 0}",
    5314: "\\Xi_b^{*-}",
    -5314: "\\Xi_b^{*+}",
    5324: "\\Xi_b^{*0}",
    5332: "\\Omega_b^-",
    -5332: "\\Omega_b^+",
    5334: "\\Omega_b^{*-}",
    -5334: "\\Omega_b^{*+}",
    5142: "\\Xi_{bc}^0",
    5242: "\\Xi_{bc}^+",
    -5242: "\\Xi_{bc}^-",
    5412: "\\Xi_{bc}^{\\prime 0}",
    5422: "\\Xi_{bc}^{\\prime +}",
    -5422: "\\Xi_{bc}^{\\prime -}",
    5414: "\\Xi_{bc}^{*0}",
    5424: "\\Xi_{bc}^{*+}",
    -5424: "\\Xi_{bc}^{*-}",
    5342: "\\Omega_{bc}^0",
    5432: "\\Omega_{bc}^{\\prime 0}",
    5434: "\\Omega_{bc}^{*0}",
    5442: "\\Omega_{bcc}^+",
    -5442: "\\Omega_{bcc}^-",
    5444: "\\Omega_{bcc}^{*+}",
    -5444: "\\Omega_{bcc}^{*-}",

    #  Bottom Baryons
    5512: "\\Xi_{bb}^-",
    -5512: "\\Xi_{bb}^+",
    5522: "\\Xi_{bb}^0",
    5514: "\\Xi_{bb}^{*-}",
    -5514: "\\Xi_{bb}^{*+}",
    5524: "\\Xi_{bb}^{*0}",
    5532: "\\Omega_{bb}^-",
    -5532: "\\Omega_{bb}^+",
    5534: "\\Omega_{bb}^{*-}",
    -5534: "\\Omega_{bb}^{*+}",
    5542: "\\Omega_{bbc}^0",
    5544: "\\Omega_{bbc}^{*0}",
    5554: "\\Omega_{bbb}^-",
    -5554: "\\Omega_{bbb}^+",
}

for i in range(81, 100 + 1):
    PDG_CODES[i] = "MC internal use"
    PDG_CODES[-i] = "MC internal use"

# Complete the missing antiparticles
for i in list(PDG_CODES.keys()):
    if i > 0 and -i not in PDG_CODES:
        PDG_CODES[-i] = "anti-" + PDG_CODES[i]

del i
